@@ -1,15 +1,15 @@
 package Mail::Sendmail;
-# Mail::Sendmail by Milivoj Ivkovic <mi@alma.ch>
+# Mail::Sendmail by Milivoj Ivkovic <mi\x40alma.ch>
 # see embedded POD documentation after __END__
-# or http://alma.ch/perl/mail.htm
+# or http://alma.ch/perl/mail.html
 
 =head1 NAME
 
-Mail::Sendmail v. 0.76 - Simple platform independent mailer
+Mail::Sendmail v. 0.79 - Simple platform independent mailer
 
 =cut
 
-$VERSION = '0.76';
+$VERSION = '0.79';
 
 # *************** Configuration you may want to change *******************
 # You probably want to set your SMTP server here (unless you specify it in
@@ -17,7 +17,7 @@ $VERSION = '0.76';
 
 %mailcfg = (
     # List of SMTP servers:
-    'smtp'    => [ qw( localhost smtp.site1.csi.com ) ],
+    'smtp'    => [ qw( localhost ) ],
     #'smtp'    => [ qw( mail.mydomain.com ) ], # example
 
     'from'    => '', # default sender e-mail, used when no From header in mail
@@ -42,11 +42,6 @@ use vars qw(
             @EXPORT
             @EXPORT_OK
             %mailcfg
-            $default_smtp_server
-            $default_smtp_port
-            $default_sender
-            $TZ
-            $use_MIME
             $address_rx
             $debug
             $log
@@ -57,6 +52,7 @@ use vars qw(
 
 use Socket;
 use Time::Local; # for automatic time zone detection
+use Sys::Hostname; # for use of hostname in HELO
 
 # use MIME::QuotedPrint if available and configured in %mailcfg
 eval("use MIME::QuotedPrint");
@@ -67,10 +63,6 @@ $mailcfg{'mime'} &&= (!$@);
 @EXPORT_OK  = qw(
                  %mailcfg
                  time_to_date
-                 $default_smtp_server
-                 $default_smtp_port
-                 $default_sender
-                 $TZ
                  $address_rx
                  $debug
                  $log
@@ -80,15 +72,15 @@ $mailcfg{'mime'} &&= (!$@);
 # regex for e-mail addresses where full=$1, user=$2, domain=$3
 # see pod documentation about this regex
 
-my $word_rx = '[\x21\x23-\x27\x2A-\x2B\x2D\w\x3D\x3F]+';
+my $word_rx = '[\x21\x23-\x27\x2A-\x2B\x2D\x2F\w\x3D\x3F]+';
 my $user_rx = $word_rx         # valid chars
              .'(?:\.' . $word_rx . ')*' # possibly more words preceded by a dot
              ;
-my $dom_rx = '\w[-\w]+(?:\.\w[-\w]+)*'; # less valid chars in domain names
+my $dom_rx = '\w[-\w]*(?:\.\w[-\w]*)*'; # less valid chars in domain names
 my $ip_rx = '\[\d{1,3}(?:\.\d{1,3}){3}\]';
 
-$address_rx = '\b((' . $user_rx . ')\@(' . $dom_rx . '\b|' . $ip_rx . '))';
-; # v. 0.4
+$address_rx = '((' . $user_rx . ')\@(' . $dom_rx . '|' . $ip_rx . '))';
+; # v. 0.61
 
 sub time_to_date {
     # convert a time() value to a date-time string according to RFC 822
@@ -101,12 +93,11 @@ sub time_to_date {
     my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)
         = localtime($time);
 
-    $TZ ||= $mailcfg{'tz'};
-
+    my $TZ = $mailcfg{'tz'};
     if ( $TZ eq "" ) {
         # offset in hours
         my $offset  = sprintf "%.1f", (timegm(localtime) - time) / 3600;
-        my $minutes = sprintf "%02d", ( $offset - int($offset) ) * 60;
+        my $minutes = sprintf "%02d", abs( $offset - int($offset) ) * 60;
         $TZ  = sprintf("%+03d", int($offset)) . $minutes;
     }
     return join(" ",
@@ -114,27 +105,27 @@ sub time_to_date {
                      $mday,
                      $months[$mon],
                      $year+1900,
-                     sprintf("%02d", $hour) . ":" . sprintf("%02d", $min),
+                     sprintf("%02d:%02d:%02d", $hour, $min, $sec),
                      $TZ
                );
 } # end sub time_to_date
 
 sub sendmail {
-    # original sendmail 1.21 by Christian Mallwitz.
-    # Modified and 'modulized' by mi@alma.ch
 
     $error = '';
     $log = "Mail::Sendmail v. $VERSION - "    . scalar(localtime()) . "\n";
 
+    my $CRLF = "\015\012";
+    local $/ = $CRLF;
+    local $\ = ''; # to protect us from outside settings
     local $_;
-    local $/ = "\015\012";
 
     my (%mail, $k,
-        $smtp, $server, $port,
-        $message, $fromaddr, $recip, @recipients, $to, $header,
-        $smtpaddr, $localhost,
+        $smtp, $server, $port, $connected, $localhost,
+        $fromaddr, $recip, @recipients, $to, $header,
        );
 
+    # -------- a few internal subs ----------
     sub fail {
         # things to do before returning a sendmail failure
         print STDERR @_ if $^W;
@@ -143,6 +134,38 @@ sub sendmail {
         return 0;
     }
 
+    sub socket_write {
+        my $i;
+        for $i (0..$#_) {
+            # accept references, so we don't copy potentially big data
+            my $data = ref($_[$i]) ? $_[$i] : \$_[$i];
+            if ($mailcfg{'debug'} > 5) {
+                if (length($$data) < 500) {
+                    print ">", $$data;
+                }
+                else {
+                    print "> [...", length($$data), " bytes sent ...]\n";
+                }
+            }
+            print(S $$data) || return 0;
+        }
+        1;
+    }
+
+    sub socket_read {
+        my $response; # for multi-line server responses
+        do {
+            chomp($_ = <S>);
+            print "<$_\n" if $mailcfg{'debug'} > 5;
+            if (/^[45]/ or !$_) {
+                return; # return false
+            }
+            $response .= $_;
+         } while (/^[\d]+-/);
+         return $response;
+    }
+    # -------- end of internal subs ----------
+
     # all config keys to lowercase, to prevent typo errors
     foreach $k (keys %mailcfg) {
         if ($k =~ /[A-Z]/) {
@@ -150,20 +173,24 @@ sub sendmail {
         }
     }
 
-    # redo hash, arranging keys case etc...
+    # redo mail hash, arranging keys case etc...
     while (@_) {
-        # arrange keys case
-        $k = ucfirst lc(shift @_);
-
+        $k = shift @_;
         if (!$k and $^W) {
             warn "Received false mail hash key: \'$k\'. Did you forget to put it in quotes?\n";
         }
 
+        # arrange keys case
+        $k = ucfirst lc($k);
+
         $k =~ s/\s*:\s*$//o; # kill colon (and possible spaces) at end, we add it later.
+        # uppercase also after "-", so people don't complain that headers case is different
+        # than in Outlook.
+        $k =~ s/-(.)/"-" . uc($1)/ge;
         $mail{$k} = shift @_;
     }
 
-    $smtp = $mail{'Smtp'} || $mail{'Server'} || $default_smtp_server;
+    $smtp = $mail{'Smtp'} || $mail{'Server'};
     unshift @{$mailcfg{'smtp'}}, $smtp if ($smtp and $mailcfg{'smtp'}->[0] ne $smtp);
 
     # delete non-header keys, so we don't send them later as mail headers
@@ -172,24 +199,21 @@ sub sendmail {
     # so instead:
     delete $mail{'Smtp'}; delete $mail{'Server'};
 
-    $mailcfg{'port'} = $mail{'Port'} || $default_smtp_port || $mailcfg{'port'} || 25;
+    $mailcfg{'port'} = $mail{'Port'} || $mailcfg{'port'} || 25;
     delete $mail{'Port'};
 
-    # for backward compatibility only
-    $mailcfg{'retries'} = $connect_retries if defined($connect_retries);
-    $mailcfg{'delay'} = $retry_delay if defined($retry_delay);
-
     {    # don't warn for undefined values below
         local $^W = 0;
-        $message = join("", $mail{'Message'}, $mail{'Body'}, $mail{'Text'});
+        $mail{'Message'} = join("", $mail{'Message'}, $mail{'Body'}, $mail{'Text'});
     }
 
-    # delete @mail{'Message', 'Body', 'Text'};
-    delete $mail{'Message'}; delete $mail{'Body'}; delete $mail{'Text'};
+    # delete @mail{'Body', 'Text'};
+    delete $mail{'Body'}; delete $mail{'Text'};
 
-    # Extract 'From:' e-mail address
+    # Extract 'From:' e-mail address to use as envelope sender
 
-    $fromaddr = $mail{'From'} || $default_sender || $mailcfg{'from'};
+    $fromaddr = $mail{'Sender'} || $mail{'From'} || $mailcfg{'from'};
+    delete $mail{'Sender'};
     unless ($fromaddr =~ /$address_rx/) {
         return fail("Bad or missing From address: \'$fromaddr\'");
     }
@@ -200,31 +224,31 @@ sub sendmail {
     $log .= "Date: $mail{Date}\n";
 
     # cleanup message, and encode if needed
-    $message =~ s/^\./\.\./gom;     # handle . as first character
-    $message =~ s/\r\n/\n/go;     # normalize line endings, step 1 of 2 (next step after MIME encoding)
+    $mail{'Message'} =~ s/\r\n/\n/go;     # normalize line endings, step 1 of 2 (next step after MIME encoding)
 
-    $mail{'Mime-version'} ||= '1.0';
-    $mail{'Content-type'} ||= 'text/plain; charset="iso-8859-1"';
+    $mail{'Mime-Version'} ||= '1.0';
+    $mail{'Content-Type'} ||= 'text/plain; charset="iso-8859-1"';
 
-    unless ( $mail{'Content-transfer-encoding'}
-          || $mail{'Content-type'} =~ /multipart/io )
+    unless ( $mail{'Content-Transfer-Encoding'}
+          || $mail{'Content-Type'} =~ /multipart/io )
     {
         if ($mailcfg{'mime'}) {
-            $mail{'Content-transfer-encoding'} = 'quoted-printable';
-            $message = encode_qp($message);
+            $mail{'Content-Transfer-Encoding'} = 'quoted-printable';
+            $mail{'Message'} = encode_qp($mail{'Message'});
         }
         else {
-            $mail{'Content-transfer-encoding'} = '8bit';
-            if ($message =~ /[\x80-\xFF]/o) {
+            $mail{'Content-Transfer-Encoding'} = '8bit';
+            if ($mail{'Message'} =~ /[\x80-\xFF]/o) {
                 $error .= "MIME::QuotedPrint not present!\nSending 8bit characters, hoping it will come across OK.\n";
                 warn "MIME::QuotedPrint not present!\n",
-                     "Sending 8bit characters, hoping it will come across OK.\n"
+                     "Sending 8bit characters without encoding, hoping it will come across OK.\n"
                      if $^W;
             }
         }
     }
 
-    $message =~ s/\n/\015\012/go; # normalize line endings, step 2.
+    $mail{'Message'} =~ s/^\./\.\./gom;     # handle . as first character
+    $mail{'Message'} =~ s/\n/$CRLF/go; # normalize line endings, step 2.
 
     # Get recipients
     {    # don't warn for undefined values below
@@ -243,40 +267,41 @@ sub sendmail {
     }
 
     # get local hostname for polite HELO
-    $localhost = (gethostbyname('localhost'))[0] || 'localhost';
+    $localhost = hostname() || 'localhost';
 
-    # open socket and start mail session
-    unless ( socket S, AF_INET, SOCK_STREAM, (getprotobyname 'tcp')[2] ) {
-        return fail("socket failed ($!)")
-    }
-
-    my $connected = 0;
     foreach $server ( @{$mailcfg{'smtp'}} ) {
-    	print "- trying $server\n" if $mailcfg{'debug'} > 1;
+        # open socket needs to be inside this foreach loop on Linux,
+        # otherwise all servers fail if 1st one fails !??! why?
+        unless ( socket S, AF_INET, SOCK_STREAM, scalar(getprotobyname 'tcp') ) {
+            return fail("socket failed ($!)")
+        }
+
+        print "- trying $server\n" if $mailcfg{'debug'} > 1;
+
         $server =~ s/\s+//go; # remove spaces just in case of a typo
         # extract port if server name like "mail.domain.com:2525"
-        ($server =~ s/:(.+)$//o) ? $port = $1    : $port = $mailcfg{'port'};
-		$smtp = $server; # so we have $smtp after the foreach
-        $smtpaddr = inet_aton $server;
+        $port = ($server =~ s/:(\d+)$//o) ? $1 : $mailcfg{'port'};
+        $smtp = $server; # save $server for use outside foreach loop
+
+        my $smtpaddr = inet_aton $server;
         unless ($smtpaddr) {
             $error .= "$server not found\n";
             next; # next server
         }
 
-        # connect sometimes failed with no obvious reason.
-        # maybe retries can help?
-        my $retried = 0;
-        while ( (not $connected = connect S, pack_sockaddr_in($port, $smtpaddr) )
-            and ($retried < $mailcfg{'retries'})
+        my $retried = 0; # reset retries for each server
+        while ( ( not $connected = connect S, pack_sockaddr_in($port, $smtpaddr) )
+            and ( $retried < $mailcfg{'retries'} )
               ) {
             $retried++;
             $error .= "connect to $server failed ($!)\n";
             print "- connect to $server failed ($!)\n" if $mailcfg{'debug'} > 1;
-            print "retrying in $mailcfg{'delay'} seconds...\n";
+            print "retrying in $mailcfg{'delay'} seconds...\n" if $mailcfg{'debug'} > 1;
             sleep $mailcfg{'delay'};
         }
 
         if ( $connected ) {
+            print "- connected to $server\n" if $mailcfg{'debug'} > 3;
             last;
         }
         else {
@@ -291,57 +316,48 @@ sub sendmail {
     };
 
     {
-	    local $^W = 0; # don't warn on undefined variables
-    	# Add info to log variable
-	    $log .= "Server: $smtp Port: $port\n"
+        local $^W = 0; # don't warn on undefined variables
+        # Add info to log variable
+        $log .= "Server: $smtp Port: $port\n"
               . "From: $fromaddr\n"
               . "Subject: $mail{Subject}\n"
               . "To: ";
-	}
+    }
 
     my($oldfh) = select(S); $| = 1; select($oldfh);
 
-    chomp($_ = <S>);
-    if (/^[45]/ or !$_) {
-        return fail("Connection error from $smtp on port $port ($_)")
-    }
-
-    print S "HELO $localhost\015\012";
-    chomp($_ = <S>);
-    if (/^[45]/ or !$_) {
-        return fail("HELO error ($_)")
-    }
-    
-    print S "mail from: <$fromaddr>\015\012";
-    chomp($_ = <S>);
-    if (/^[45]/ or !$_) {
-        return fail("mail From: error ($_)")
-    }
+    socket_read()
+        || return fail("Connection error from $smtp on port $port ($_)");
+    socket_write("HELO $localhost$CRLF")
+        || return fail("send HELO error");
+    socket_read()
+        || return fail("HELO error ($_)");
+    socket_write("MAIL FROM: <$fromaddr>$CRLF")
+        || return fail("send MAIL FROM: error");
+    socket_read()
+        || return fail("MAIL FROM: error ($_)");
 
     foreach $to (@recipients) {
-        if ($debug) { print STDERR "sending to: <$to>\n"; }
-        print S "rcpt to: <$to>\015\012";
-        chomp($_ = <S>);
-        if (/^[45]/ or !$_) {
-            $log .= "!Failed: $to\n    ";
-            return fail("Error sending to <$to> ($_)\n");
-        }
-        else {
-            $log .= "$to\n    ";
-        }
+        socket_write("RCPT TO: <$to>$CRLF")
+            || return fail("send RCPT TO: error");
+        socket_read()
+            || return fail("RCPT TO: error ($_)");
+        $log .= "$to\n    ";
     }
 
     # start data part
-    print S "data\015\012";
-    chomp($_ = <S>);
-    if (/^[45]/ or !$_) {
-           return fail("Cannot send data ($_)");
-    }
+
+    socket_write("DATA$CRLF")
+        || return fail("send DATA error");
+    socket_read()
+        || return fail("DATA error ($_)");
 
     # print headers
     foreach $header (keys %mail) {
+        next if $header eq "Message";
         $mail{$header} =~ s/\s+$//o; # kill possible trailing garbage
-        print S "$header: ", $mail{$header}, "\015\012";
+        socket_write("$header: $mail{$header}$CRLF")
+            || return fail("send $header: error");
     };
 
     #- test diconnecting from network here, to see what happens
@@ -349,19 +365,17 @@ sub sendmail {
     #- sleep 4;
     #- print STDERR "trying to continue, expecting an error... \n";
 
-    # send message body
-    print S "\015\012",
-            $message,
-            "\015\012.\015\012";
-
-    chomp($_ = <S>);
-    if (/^[45]/ or !$_) {
-           return fail("message transmission failed ($_)");
-    }
+    # send message body (passed as a reference, in case it's big)
+    socket_write($CRLF, \$mail{'Message'}, "$CRLF.$CRLF")
+           || return fail("send message error");
+    socket_read()
+        || return fail("message transmission error ($_)");
+    $log .= "\nResult: $_";
 
     # finish
-    print S "quit\015\012";
-    $_ = <S>;
+    socket_write("QUIT$CRLF")
+           || return fail("send QUIT error");
+    socket_read();
     close S;
 
     return 1;
@@ -388,19 +402,19 @@ __END__
 Simple platform independent e-mail from your perl script. Only requires
 Perl 5 and a network connection.
 
-After struggling for some time with various command-line mailing programs
-which never did exactly what I wanted, I put together this Perl only
-solution.
-
 Mail::Sendmail contains mainly &sendmail, which takes a hash with the
 message to send and sends it. It is intended to be very easy to setup and
-use.
+use. See also L<"FEATURES"> below.
 
 =head1 INSTALLATION
 
 =over 4
 
-=item Standard
+=item Best
+
+C<perl -MCPAN -e "install Mail::Sendmail">
+
+=item Traditional
 
     perl Makefile.PL
     make
@@ -411,38 +425,36 @@ use.
 
 Copy Sendmail.pm to Mail/ in your Perl lib directory.
 
-    (eg. c:\Perl\lib\Mail\, c:\Perl\site\lib\Mail\,
-     /usr/lib/perl5/site_perl/Mail/, ... or whatever it
-     is on your system)
+    (eg. c:\Perl\site\lib\Mail\
+     or  /usr/lib/perl5/site_perl/Mail/
+     or whatever it is on your system.
+     They are listed when you type C< perl -V >)
 
 =item ActivePerl's PPM
 
 ppm install --location=http://alma.ch/perl/ppm Mail-Sendmail
 
-But this way you don't get a chance to have a look at other files (Changes, 
-Todo, test.pl, ...) and PPM doesn't run the test script (test.pl).
+But this way you don't get a chance to have a look at other files (Changes,
+Todo, test.pl, ...).
 
 =back
 
-At the top of Sendmail.pm, set your default SMTP server, unless you specify
-it with each message, or want to use the default.
+At the top of Sendmail.pm, set your default SMTP server(s), unless you specify
+it with each message, or want to use the default (localhost).
 
 Install MIME::QuotedPrint. This is not required but strongly recommended.
 
 =head1 FEATURES
 
-Automatic Mime quoted printable encoding (if MIME::QuotedPrint installed)
+Automatic time zone detection, Date: header, MIME quoted-printable encoding
+(if MIME::QuotedPrint installed), all of which can be overridden.
 
-Internal Bcc: and Cc: support (even on broken servers)
+Bcc: and Cc: support.
 
-Allows real names in From: and To: fields
+Allows real names in From:, To: and Cc: fields
 
-Doesn't send unwanted headers, and allows you to send any header(s) you
-want
-
-Adds the Date header if you don't supply your own
-
-Automatic Time Zone detection
+Doesn't send an X-Mailer: header (unless you do), and allows you to send any
+header(s) you want.
 
 Configurable retries and use of alternate servers if your mail server is
 down
@@ -453,12 +465,15 @@ Good plain text error reporting
 
 Headers are not encoded, even if they have accented characters.
 
-Since the whole message is in memory (twice!), it's not suitable for 
+No suport for the SMTP AUTH extension.
+
+Since the whole message is in memory, it's not suitable for
 sending very big attached files.
 
 The SMTP server has to be set manually in Sendmail.pm or in your script,
-unless you can live with the default (localhost or Compuserve's
-smpt.site1.csi.com).
+unless you have a mail server on localhost.
+
+Doesn't work on OpenVMS, I was told. Cannot test this myself.
 
 =head1 CONFIGURATION
 
@@ -478,8 +493,8 @@ from your script, which will do the same thing:
 
 C<$mail{smtp} = 'my.mail.server';>
 
-A future version will try to set useful defaults for you during the
-Makefile.PL.
+A future version will (hopefully) try to set useful defaults for you
+during the Makefile.PL.
 
 =item Other configuration settings
 
@@ -505,23 +520,28 @@ Keys are NOT case-sensitive.
 
 The colon after headers is not necessary.
 
-The Body part key can be called 'Body', 'Message' or 'Text'. The SMTP
-server key can be called 'Smtp' or 'Server'.
+The Body part key can be called 'Body', 'Message' or 'Text'.
+
+The SMTP server key can be called 'Smtp' or 'Server'. If the connection to
+this one fails, the other ones in C<$mailcfg{smtp}> will still be tried.
 
 The following headers are added unless you specify them yourself:
 
-    Mime-version: 1.0
-    Content-type: 'text/plain; charset="iso-8859-1"'
+    Mime-Version: 1.0
+    Content-Type: 'text/plain; charset="iso-8859-1"'
 
-    Content-transfer-encoding: quoted-printable
+    Content-Transfer-Encoding: quoted-printable
     or (if MIME::QuotedPrint not installed)
-    Content-transfer-encoding: 8bit
+    Content-Transfer-Encoding: 8bit
 
     Date: [string returned by time_to_date()]
 
+If you wish to use an envelope sender address different than the
+From: address, set C<$mail{Sender}> in your %mail hash.
+
 The following are not exported by default, but you can still access them
 with their full name, or request their export on the use line like in:
-C<use Mail::Sendmail qw($address_rx time_to_date);>
+C<use Mail::Sendmail qw(sendmail $address_rx time_to_date);>
 
 =head2 Mail::Sendmail::time_to_date()
 
@@ -560,7 +580,8 @@ characters that would need to be quoted are not supported.
 
 This hash contains all configuration options. You normally edit it once (if
 ever) in Sendmail.pm and forget about it, but you could also access it from
-your scripts. For readability, I'll assume you have imported it.
+your scripts. For readability, I'll assume you have imported it
+(with something like C<use Mail::Sendmail qw(sendmail %mailcfg)>).
 
 The keys are not case-sensitive: they are all converted to lowercase before
 use. Writing C<$mailcfg{Port} = 2525;> is OK: the default $mailcfg{port}
@@ -570,14 +591,14 @@ use. Writing C<$mailcfg{Port} = 2525;> is OK: the default $mailcfg{port}
 
 =item $mailcfg{smtp}
 
-C<$mailcfg{smtp} = [qw(localhost smtp.site1.csi.com)];>
+C<$mailcfg{smtp} = [qw(localhost my.other.mail.server)];>
 
 This is a reference to a list of smtp servers, so if your main server is
 down, the module tries the next one. If one of your servers uses a special
 port, add it to the server name with a colon in front, to override the
 default port (like in my.special.server:2525).
 
-Default: localhost and smtp.site1.csi.com (which seems to be an open relay)
+Default: localhost.
 
 =item $mailcfg{from}
 
@@ -642,10 +663,10 @@ Default: 25.
 
 =item $mailcfg{debug}
 
-C<$mailcfg{debug} => 0;>
+C<$mailcfg{debug} = 0;>
 
-Prints stuff to STDERR. Not used much, and what is printed may change
-without notice. Don't count on it.
+Prints stuff to STDERR. Current maximum is 6, which prints the whole SMTP
+session, except data exceeding 500 bytes.
 
 Default: 0;
 
@@ -657,7 +678,10 @@ The package version number (you can not import this one)
 
 =head2 Configuration variables from previous versions
 
-The following global variables were used in version 0.74 for configuration. They should still work, but will not in a future version (unless you complain loudly). Please use I<%mailcfg> if you need to access the configuration from your scripts.
+The following global variables were used in version 0.74 for configuration.
+As from version 0.78_1, they are not supported anymore.
+Use the I<%mailcfg> hash if you need to access the configuration
+from your scripts.
 
 =over 4
 
@@ -675,9 +699,6 @@ The following global variables were used in version 0.74 for configuration. They
 
 =item $Mail::Sendmail::use_MIME
 
-This one couldn't really be used in the previous version, so I just dropped it.
-It is replaced by I<$mailcfg{mime}> which works.
-
 =back
 
 =head1 ANOTHER EXAMPLE
@@ -704,43 +725,78 @@ It is replaced by I<$mailcfg{mime}> which works.
   $mail{'X-custom'} = 'My custom additionnal header';
   $mail{'mESSaGE : '} = "The message key looks terrible, but works.";
   # cheat on the date:
-  $mail{Date} = Mail::Sendmail::time_to_date( time() - 86400 ),
+  $mail{Date} = Mail::Sendmail::time_to_date( time() - 86400 );
 
   if (sendmail %mail) { print "Mail sent OK.\n" }
   else { print "Error sending mail: $Mail::Sendmail::error \n" }
 
   print "\n\$Mail::Sendmail::log says:\n", $Mail::Sendmail::log;
+ 
+Also see http://alma.ch/perl/Mail-Sendmail-FAQ.html for examples
+of HTML mail and sending attachments. 
 
 =head1 CHANGES
 
-Many changes and bug-fixes since version 0.74. In short: less code, more 
-functionality and docs. See the F<Changes> file.
+Main changes since version 0.78:
+
+Added "/" (\x2F) as a valid character in mailbox part.
+
+Removed old configuration variables which are not used anymore
+since version 0.74.
+
+Added support for different envelope sender (through C<$mail{Sender}>)
+
+Changed case of headers: first character after "-" also uppercased
+
+Support for multi-line server responses
+
+Localized $\ and $_
+
+Some internal rewrites and documentation updates
+
+Fixed old bug of dot as 76th character on line disappearing.
+
+Fixed very old bug where port number was not extracted from
+stuff like 'my.server:2525'.
+
+Fixed time_to_date bug with negative half-hour zones (only Newfoundland?)
+
+Added seconds to date string
+
+Now uses Sys::Hostname to get the hostname for HELO. (This may break the
+module on some very old Win32 Perls where Sys::Hostname was broken)
+
+Enable full session output for debugging
+
+See the F<Changes> file for the full history. If you don't have it
+because you installed through PPM, you can also find the latest
+one on F<http://alma.ch/perl/scripts/Sendmail/Changes>.
 
 =head1 AUTHOR
 
-Milivoj Ivkovic mi@alma.ch or ivkovic@csi.com
+Milivoj Ivkovic <mi\x40alma.ch> ("\x40" is "@" of course)
 
 =head1 NOTES
 
-MIME::QuotedPrint is used by default on every message if available. It 
-allows reliable sending of accented characters, and also takes care of 
-too long lines (which can happen in HTML mails). It is available in the 
-MIME-Base64 package at http://www.perl.com/CPAN/modules/by-module/MIME/ or 
+MIME::QuotedPrint is used by default on every message if available. It
+allows reliable sending of accented characters, and also takes care of
+too long lines (which can happen in HTML mails). It is available in the
+MIME-Base64 package at http://www.perl.com/CPAN/modules/by-module/MIME/ or
 through PPM.
 
-Look at http://alma.ch/perl/Mail-Sendmail-FAQ.htm for additional info 
-(CGI, examples of sending attachments, HTML mail etc...)
+Look at http://alma.ch/perl/Mail-Sendmail-FAQ.html for additional
+info (CGI, examples of sending attachments, HTML mail etc...)
 
-You can use it freely. (Someone complained this is too vague. So, more
-precisely: do whatever you want with it, but be warned that terrible things
-will happen to you if you use it badly, like for sending spam, claiming you
-wrote it alone, or ...?)
+You can use this module freely. (Someone complained this is too vague.
+So, more precisely: do whatever you want with it, but be warned that
+terrible things will happen to you if you use it badly, like for sending
+spam, or ...?)
 
-I would appreciate a short (or long) e-mail note if you use this (and even
-if you don't, especially if you care to say why). And of course,
-bug-reports and/or suggestions are welcome.
+Thanks to the many users who sent me feedback, bug reports, suggestions, etc.
+And please excuse me if I forgot to answer your mail. I am not always reliabe
+in answering mail. I intend to set up a mailing list soon.
 
-Last revision: 27.03.99. Latest version should be available at
-http://alma.ch/perl/mail.htm , and a few days later on CPAN.
+Last revision: 06.02.2003. Latest version should be available on
+CPAN: F<http://www.cpan.org/modules/by-authors/id/M/MI/MIVKOVIC/>.
 
 =cut
